# w.c.s. - web application for online forms
# Copyright (C) 2005-2019  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

from quixote import get_publisher
from quixote.directory import Directory
from quixote.html import TemplateIO, htmltext

from wcs.admin.logged_errors import LoggedErrorsDirectory
from wcs.qommon import _
from wcs.qommon import template
from wcs.qommon.backoffice.menu import html_top
from wcs.qommon.form import get_response


class StudioDirectory(Directory):
    _q_exports = ['', ('logged-errors', 'logged_errors_dir')]

    def __init__(self):
        self.logged_errors_dir = LoggedErrorsDirectory(parent_dir=self)

    def get_sidebar(self):
        r = TemplateIO(html=True)
        r += htmltext('<ul id="sidebar-actions">')
        r += htmltext('<li><a href="logged-errors/">%s</a></li>') % _('Logged Errors')
        r += htmltext('</ul>')
        return r.getvalue()

    def html_top(self, title):
        return html_top('studio', title)

    def _q_traverse(self, path):
        get_response().breadcrumb.append(('studio/', _('Studio')))
        return super()._q_traverse(path)

    def _q_index(self):
        self.html_top(_('Studio'))
        get_response().filter['sidebar'] = self.get_sidebar()
        return template.QommonTemplateResponse(
                templates=['wcs/backoffice/studio.html'],
                context={})

    @classmethod
    def is_visible(cls, *args):
        return get_publisher().has_site_option('studio')

    def is_accessible(self, user):
        backoffice_root = get_publisher().get_backoffice_root()
        return (backoffice_root.is_accessible('forms') or
                backoffice_root.is_accessible('workflows') or
                backoffice_root.is_accessible('cards'))
