# w.c.s. - web application for online forms
# Copyright (C) 2005-2017  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import os
import quixote

from django.core.management.base import BaseCommand
from wcs.qommon.publisher import get_publisher_class


class Command(BaseCommand):
    help = 'Migrate databases'

    def handle(self, verbosity=1, **options):
        Publisher = get_publisher_class()
        quixote.cleanup()
        pub = Publisher.create_publisher()
        base_app_dir = pub.app_dir
        for hostname in Publisher.get_tenants():
            tenant_path = os.path.join(base_app_dir, hostname)
            if not os.path.exists(os.path.join(tenant_path, 'config.pck')):
                continue
            pub = Publisher.create_publisher()
            pub.app_dir = tenant_path
            pub.set_config()
            if pub.is_using_postgresql():
                if verbosity:
                    print('Running migrations for', hostname)
                pub.migrate_sql()
                pub.cleanup()
            quixote.cleanup()
